# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UnifiedAgentConfiguration(object):
    """
    Top Unified Agent configuration object.
    """

    #: A constant which can be used with the lifecycle_state property of a UnifiedAgentConfiguration.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a UnifiedAgentConfiguration.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a UnifiedAgentConfiguration.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a UnifiedAgentConfiguration.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a UnifiedAgentConfiguration.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a UnifiedAgentConfiguration.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the configuration_state property of a UnifiedAgentConfiguration.
    #: This constant has a value of "VALID"
    CONFIGURATION_STATE_VALID = "VALID"

    #: A constant which can be used with the configuration_state property of a UnifiedAgentConfiguration.
    #: This constant has a value of "INVALID"
    CONFIGURATION_STATE_INVALID = "INVALID"

    def __init__(self, **kwargs):
        """
        Initializes a new UnifiedAgentConfiguration object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this UnifiedAgentConfiguration.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this UnifiedAgentConfiguration.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this UnifiedAgentConfiguration.
        :type display_name: str

        :param description:
            The value to assign to the description property of this UnifiedAgentConfiguration.
        :type description: str

        :param defined_tags:
            The value to assign to the defined_tags property of this UnifiedAgentConfiguration.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UnifiedAgentConfiguration.
        :type freeform_tags: dict(str, str)

        :param time_created:
            The value to assign to the time_created property of this UnifiedAgentConfiguration.
        :type time_created: datetime

        :param time_last_modified:
            The value to assign to the time_last_modified property of this UnifiedAgentConfiguration.
        :type time_last_modified: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this UnifiedAgentConfiguration.
            Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "INACTIVE", "DELETING", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param is_enabled:
            The value to assign to the is_enabled property of this UnifiedAgentConfiguration.
        :type is_enabled: bool

        :param configuration_state:
            The value to assign to the configuration_state property of this UnifiedAgentConfiguration.
            Allowed values for this property are: "VALID", "INVALID", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type configuration_state: str

        :param service_configuration:
            The value to assign to the service_configuration property of this UnifiedAgentConfiguration.
        :type service_configuration: oci.logging.models.UnifiedAgentServiceConfigurationDetails

        :param group_association:
            The value to assign to the group_association property of this UnifiedAgentConfiguration.
        :type group_association: oci.logging.models.GroupAssociationDetails

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'description': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)',
            'time_created': 'datetime',
            'time_last_modified': 'datetime',
            'lifecycle_state': 'str',
            'is_enabled': 'bool',
            'configuration_state': 'str',
            'service_configuration': 'UnifiedAgentServiceConfigurationDetails',
            'group_association': 'GroupAssociationDetails'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'description': 'description',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags',
            'time_created': 'timeCreated',
            'time_last_modified': 'timeLastModified',
            'lifecycle_state': 'lifecycleState',
            'is_enabled': 'isEnabled',
            'configuration_state': 'configurationState',
            'service_configuration': 'serviceConfiguration',
            'group_association': 'groupAssociation'
        }

        self._id = None
        self._compartment_id = None
        self._display_name = None
        self._description = None
        self._defined_tags = None
        self._freeform_tags = None
        self._time_created = None
        self._time_last_modified = None
        self._lifecycle_state = None
        self._is_enabled = None
        self._configuration_state = None
        self._service_configuration = None
        self._group_association = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this UnifiedAgentConfiguration.
        The OCID of the resource.


        :return: The id of this UnifiedAgentConfiguration.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this UnifiedAgentConfiguration.
        The OCID of the resource.


        :param id: The id of this UnifiedAgentConfiguration.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this UnifiedAgentConfiguration.
        The OCID of the compartment that the resource belongs to.


        :return: The compartment_id of this UnifiedAgentConfiguration.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this UnifiedAgentConfiguration.
        The OCID of the compartment that the resource belongs to.


        :param compartment_id: The compartment_id of this UnifiedAgentConfiguration.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this UnifiedAgentConfiguration.
        The user-friendly display name. This must be unique within the enclosing resource,
        and it's changeable. Avoid entering confidential information.


        :return: The display_name of this UnifiedAgentConfiguration.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UnifiedAgentConfiguration.
        The user-friendly display name. This must be unique within the enclosing resource,
        and it's changeable. Avoid entering confidential information.


        :param display_name: The display_name of this UnifiedAgentConfiguration.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this UnifiedAgentConfiguration.
        Description for this resource.


        :return: The description of this UnifiedAgentConfiguration.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UnifiedAgentConfiguration.
        Description for this resource.


        :param description: The description of this UnifiedAgentConfiguration.
        :type: str
        """
        self._description = description

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UnifiedAgentConfiguration.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UnifiedAgentConfiguration.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UnifiedAgentConfiguration.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UnifiedAgentConfiguration.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UnifiedAgentConfiguration.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UnifiedAgentConfiguration.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UnifiedAgentConfiguration.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UnifiedAgentConfiguration.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def time_created(self):
        """
        Gets the time_created of this UnifiedAgentConfiguration.
        Time the resource was created.


        :return: The time_created of this UnifiedAgentConfiguration.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this UnifiedAgentConfiguration.
        Time the resource was created.


        :param time_created: The time_created of this UnifiedAgentConfiguration.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_last_modified(self):
        """
        Gets the time_last_modified of this UnifiedAgentConfiguration.
        Time the resource was last modified.


        :return: The time_last_modified of this UnifiedAgentConfiguration.
        :rtype: datetime
        """
        return self._time_last_modified

    @time_last_modified.setter
    def time_last_modified(self, time_last_modified):
        """
        Sets the time_last_modified of this UnifiedAgentConfiguration.
        Time the resource was last modified.


        :param time_last_modified: The time_last_modified of this UnifiedAgentConfiguration.
        :type: datetime
        """
        self._time_last_modified = time_last_modified

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this UnifiedAgentConfiguration.
        The pipeline state.

        Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "INACTIVE", "DELETING", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this UnifiedAgentConfiguration.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this UnifiedAgentConfiguration.
        The pipeline state.


        :param lifecycle_state: The lifecycle_state of this UnifiedAgentConfiguration.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "UPDATING", "INACTIVE", "DELETING", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def is_enabled(self):
        """
        **[Required]** Gets the is_enabled of this UnifiedAgentConfiguration.
        Whether or not this resource is currently enabled.


        :return: The is_enabled of this UnifiedAgentConfiguration.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this UnifiedAgentConfiguration.
        Whether or not this resource is currently enabled.


        :param is_enabled: The is_enabled of this UnifiedAgentConfiguration.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def configuration_state(self):
        """
        **[Required]** Gets the configuration_state of this UnifiedAgentConfiguration.
        State of unified agent service configuration.

        Allowed values for this property are: "VALID", "INVALID", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The configuration_state of this UnifiedAgentConfiguration.
        :rtype: str
        """
        return self._configuration_state

    @configuration_state.setter
    def configuration_state(self, configuration_state):
        """
        Sets the configuration_state of this UnifiedAgentConfiguration.
        State of unified agent service configuration.


        :param configuration_state: The configuration_state of this UnifiedAgentConfiguration.
        :type: str
        """
        allowed_values = ["VALID", "INVALID"]
        if not value_allowed_none_or_none_sentinel(configuration_state, allowed_values):
            configuration_state = 'UNKNOWN_ENUM_VALUE'
        self._configuration_state = configuration_state

    @property
    def service_configuration(self):
        """
        **[Required]** Gets the service_configuration of this UnifiedAgentConfiguration.

        :return: The service_configuration of this UnifiedAgentConfiguration.
        :rtype: oci.logging.models.UnifiedAgentServiceConfigurationDetails
        """
        return self._service_configuration

    @service_configuration.setter
    def service_configuration(self, service_configuration):
        """
        Sets the service_configuration of this UnifiedAgentConfiguration.

        :param service_configuration: The service_configuration of this UnifiedAgentConfiguration.
        :type: oci.logging.models.UnifiedAgentServiceConfigurationDetails
        """
        self._service_configuration = service_configuration

    @property
    def group_association(self):
        """
        **[Required]** Gets the group_association of this UnifiedAgentConfiguration.

        :return: The group_association of this UnifiedAgentConfiguration.
        :rtype: oci.logging.models.GroupAssociationDetails
        """
        return self._group_association

    @group_association.setter
    def group_association(self, group_association):
        """
        Sets the group_association of this UnifiedAgentConfiguration.

        :param group_association: The group_association of this UnifiedAgentConfiguration.
        :type: oci.logging.models.GroupAssociationDetails
        """
        self._group_association = group_association

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .action import Action
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ForwardToBackendSet(Action):
    """
    Action to forward requests to a given backend set.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ForwardToBackendSet object with values from keyword arguments. The default value of the :py:attr:`~oci.load_balancer.models.ForwardToBackendSet.name` attribute
        of this class is ``FORWARD_TO_BACKENDSET`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ForwardToBackendSet.
            Allowed values for this property are: "FORWARD_TO_BACKENDSET"
        :type name: str

        :param backend_set_name:
            The value to assign to the backend_set_name property of this ForwardToBackendSet.
        :type backend_set_name: str

        """
        self.swagger_types = {
            'name': 'str',
            'backend_set_name': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'backend_set_name': 'backendSetName'
        }

        self._name = None
        self._backend_set_name = None
        self._name = 'FORWARD_TO_BACKENDSET'

    @property
    def backend_set_name(self):
        """
        Gets the backend_set_name of this ForwardToBackendSet.
        Name of the backend set the listener will forward the traffic to.

        Example: `backendSetForImages`


        :return: The backend_set_name of this ForwardToBackendSet.
        :rtype: str
        """
        return self._backend_set_name

    @backend_set_name.setter
    def backend_set_name(self, backend_set_name):
        """
        Sets the backend_set_name of this ForwardToBackendSet.
        Name of the backend set the listener will forward the traffic to.

        Example: `backendSetForImages`


        :param backend_set_name: The backend_set_name of this ForwardToBackendSet.
        :type: str
        """
        self._backend_set_name = backend_set_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ScriptParameter(object):
    """
    Details of the script parameters, paramName must be from the script content and
    these details can be used to overwrite the default parameter present in the script content.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ScriptParameter object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param param_name:
            The value to assign to the param_name property of this ScriptParameter.
        :type param_name: str

        :param param_value:
            The value to assign to the param_value property of this ScriptParameter.
        :type param_value: str

        :param is_secret:
            The value to assign to the is_secret property of this ScriptParameter.
        :type is_secret: bool

        """
        self.swagger_types = {
            'param_name': 'str',
            'param_value': 'str',
            'is_secret': 'bool'
        }

        self.attribute_map = {
            'param_name': 'paramName',
            'param_value': 'paramValue',
            'is_secret': 'isSecret'
        }

        self._param_name = None
        self._param_value = None
        self._is_secret = None

    @property
    def param_name(self):
        """
        **[Required]** Gets the param_name of this ScriptParameter.
        Name of the parameter.


        :return: The param_name of this ScriptParameter.
        :rtype: str
        """
        return self._param_name

    @param_name.setter
    def param_name(self, param_name):
        """
        Sets the param_name of this ScriptParameter.
        Name of the parameter.


        :param param_name: The param_name of this ScriptParameter.
        :type: str
        """
        self._param_name = param_name

    @property
    def param_value(self):
        """
        Gets the param_value of this ScriptParameter.
        Value of the parameter.


        :return: The param_value of this ScriptParameter.
        :rtype: str
        """
        return self._param_value

    @param_value.setter
    def param_value(self, param_value):
        """
        Sets the param_value of this ScriptParameter.
        Value of the parameter.


        :param param_value: The param_value of this ScriptParameter.
        :type: str
        """
        self._param_value = param_value

    @property
    def is_secret(self):
        """
        Gets the is_secret of this ScriptParameter.
        If the parameter value is secret and should be kept confidential, then set isSecret to true.


        :return: The is_secret of this ScriptParameter.
        :rtype: bool
        """
        return self._is_secret

    @is_secret.setter
    def is_secret(self, is_secret):
        """
        Sets the is_secret of this ScriptParameter.
        If the parameter value is secret and should be kept confidential, then set isSecret to true.


        :param is_secret: The is_secret of this ScriptParameter.
        :type: bool
        """
        self._is_secret = is_secret

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AttributeSummary(object):
    """
    Summary of an entity attribute.
    """

    #: A constant which can be used with the lifecycle_state property of a AttributeSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a AttributeSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a AttributeSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a AttributeSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a AttributeSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a AttributeSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a AttributeSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a AttributeSummary.
    #: This constant has a value of "MOVING"
    LIFECYCLE_STATE_MOVING = "MOVING"

    #: A constant which can be used with the associated_rule_types property of a AttributeSummary.
    #: This constant has a value of "PRIMARYKEY"
    ASSOCIATED_RULE_TYPES_PRIMARYKEY = "PRIMARYKEY"

    #: A constant which can be used with the associated_rule_types property of a AttributeSummary.
    #: This constant has a value of "FOREIGNKEY"
    ASSOCIATED_RULE_TYPES_FOREIGNKEY = "FOREIGNKEY"

    #: A constant which can be used with the associated_rule_types property of a AttributeSummary.
    #: This constant has a value of "UNIQUEKEY"
    ASSOCIATED_RULE_TYPES_UNIQUEKEY = "UNIQUEKEY"

    def __init__(self, **kwargs):
        """
        Initializes a new AttributeSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this AttributeSummary.
        :type key: str

        :param display_name:
            The value to assign to the display_name property of this AttributeSummary.
        :type display_name: str

        :param business_name:
            The value to assign to the business_name property of this AttributeSummary.
        :type business_name: str

        :param description:
            The value to assign to the description property of this AttributeSummary.
        :type description: str

        :param entity_key:
            The value to assign to the entity_key property of this AttributeSummary.
        :type entity_key: str

        :param external_key:
            The value to assign to the external_key property of this AttributeSummary.
        :type external_key: str

        :param length:
            The value to assign to the length property of this AttributeSummary.
        :type length: int

        :param position:
            The value to assign to the position property of this AttributeSummary.
        :type position: int

        :param precision:
            The value to assign to the precision property of this AttributeSummary.
        :type precision: int

        :param scale:
            The value to assign to the scale property of this AttributeSummary.
        :type scale: int

        :param is_nullable:
            The value to assign to the is_nullable property of this AttributeSummary.
        :type is_nullable: bool

        :param uri:
            The value to assign to the uri property of this AttributeSummary.
        :type uri: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this AttributeSummary.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this AttributeSummary.
        :type time_created: datetime

        :param external_data_type:
            The value to assign to the external_data_type property of this AttributeSummary.
        :type external_data_type: str

        :param min_collection_count:
            The value to assign to the min_collection_count property of this AttributeSummary.
        :type min_collection_count: int

        :param max_collection_count:
            The value to assign to the max_collection_count property of this AttributeSummary.
        :type max_collection_count: int

        :param datatype_entity_key:
            The value to assign to the datatype_entity_key property of this AttributeSummary.
        :type datatype_entity_key: str

        :param external_datatype_entity_key:
            The value to assign to the external_datatype_entity_key property of this AttributeSummary.
        :type external_datatype_entity_key: str

        :param parent_attribute_key:
            The value to assign to the parent_attribute_key property of this AttributeSummary.
        :type parent_attribute_key: str

        :param external_parent_attribute_key:
            The value to assign to the external_parent_attribute_key property of this AttributeSummary.
        :type external_parent_attribute_key: str

        :param path:
            The value to assign to the path property of this AttributeSummary.
        :type path: str

        :param custom_property_members:
            The value to assign to the custom_property_members property of this AttributeSummary.
        :type custom_property_members: list[oci.data_catalog.models.CustomPropertyGetUsage]

        :param associated_rule_types:
            The value to assign to the associated_rule_types property of this AttributeSummary.
            Allowed values for items in this list are: "PRIMARYKEY", "FOREIGNKEY", "UNIQUEKEY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type associated_rule_types: list[str]

        :param is_derived_attribute:
            The value to assign to the is_derived_attribute property of this AttributeSummary.
        :type is_derived_attribute: bool

        :param time_updated:
            The value to assign to the time_updated property of this AttributeSummary.
        :type time_updated: datetime

        :param properties:
            The value to assign to the properties property of this AttributeSummary.
        :type properties: dict(str, dict(str, str))

        """
        self.swagger_types = {
            'key': 'str',
            'display_name': 'str',
            'business_name': 'str',
            'description': 'str',
            'entity_key': 'str',
            'external_key': 'str',
            'length': 'int',
            'position': 'int',
            'precision': 'int',
            'scale': 'int',
            'is_nullable': 'bool',
            'uri': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'external_data_type': 'str',
            'min_collection_count': 'int',
            'max_collection_count': 'int',
            'datatype_entity_key': 'str',
            'external_datatype_entity_key': 'str',
            'parent_attribute_key': 'str',
            'external_parent_attribute_key': 'str',
            'path': 'str',
            'custom_property_members': 'list[CustomPropertyGetUsage]',
            'associated_rule_types': 'list[str]',
            'is_derived_attribute': 'bool',
            'time_updated': 'datetime',
            'properties': 'dict(str, dict(str, str))'
        }

        self.attribute_map = {
            'key': 'key',
            'display_name': 'displayName',
            'business_name': 'businessName',
            'description': 'description',
            'entity_key': 'entityKey',
            'external_key': 'externalKey',
            'length': 'length',
            'position': 'position',
            'precision': 'precision',
            'scale': 'scale',
            'is_nullable': 'isNullable',
            'uri': 'uri',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'external_data_type': 'externalDataType',
            'min_collection_count': 'minCollectionCount',
            'max_collection_count': 'maxCollectionCount',
            'datatype_entity_key': 'datatypeEntityKey',
            'external_datatype_entity_key': 'externalDatatypeEntityKey',
            'parent_attribute_key': 'parentAttributeKey',
            'external_parent_attribute_key': 'externalParentAttributeKey',
            'path': 'path',
            'custom_property_members': 'customPropertyMembers',
            'associated_rule_types': 'associatedRuleTypes',
            'is_derived_attribute': 'isDerivedAttribute',
            'time_updated': 'timeUpdated',
            'properties': 'properties'
        }

        self._key = None
        self._display_name = None
        self._business_name = None
        self._description = None
        self._entity_key = None
        self._external_key = None
        self._length = None
        self._position = None
        self._precision = None
        self._scale = None
        self._is_nullable = None
        self._uri = None
        self._lifecycle_state = None
        self._time_created = None
        self._external_data_type = None
        self._min_collection_count = None
        self._max_collection_count = None
        self._datatype_entity_key = None
        self._external_datatype_entity_key = None
        self._parent_attribute_key = None
        self._external_parent_attribute_key = None
        self._path = None
        self._custom_property_members = None
        self._associated_rule_types = None
        self._is_derived_attribute = None
        self._time_updated = None
        self._properties = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this AttributeSummary.
        Unique attribute key that is immutable.


        :return: The key of this AttributeSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this AttributeSummary.
        Unique attribute key that is immutable.


        :param key: The key of this AttributeSummary.
        :type: str
        """
        self._key = key

    @property
    def display_name(self):
        """
        Gets the display_name of this AttributeSummary.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this AttributeSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this AttributeSummary.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this AttributeSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def business_name(self):
        """
        Gets the business_name of this AttributeSummary.
        Optional user friendly business name of the attribute. If set, this supplements the harvested display name of the object.


        :return: The business_name of this AttributeSummary.
        :rtype: str
        """
        return self._business_name

    @business_name.setter
    def business_name(self, business_name):
        """
        Sets the business_name of this AttributeSummary.
        Optional user friendly business name of the attribute. If set, this supplements the harvested display name of the object.


        :param business_name: The business_name of this AttributeSummary.
        :type: str
        """
        self._business_name = business_name

    @property
    def description(self):
        """
        Gets the description of this AttributeSummary.
        Detailed description of the attribute.


        :return: The description of this AttributeSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this AttributeSummary.
        Detailed description of the attribute.


        :param description: The description of this AttributeSummary.
        :type: str
        """
        self._description = description

    @property
    def entity_key(self):
        """
        Gets the entity_key of this AttributeSummary.
        The unique key of the parent entity.


        :return: The entity_key of this AttributeSummary.
        :rtype: str
        """
        return self._entity_key

    @entity_key.setter
    def entity_key(self, entity_key):
        """
        Sets the entity_key of this AttributeSummary.
        The unique key of the parent entity.


        :param entity_key: The entity_key of this AttributeSummary.
        :type: str
        """
        self._entity_key = entity_key

    @property
    def external_key(self):
        """
        Gets the external_key of this AttributeSummary.
        Unique external key of this attribute in the external source system.


        :return: The external_key of this AttributeSummary.
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """
        Sets the external_key of this AttributeSummary.
        Unique external key of this attribute in the external source system.


        :param external_key: The external_key of this AttributeSummary.
        :type: str
        """
        self._external_key = external_key

    @property
    def length(self):
        """
        Gets the length of this AttributeSummary.
        Max allowed length of the attribute value.


        :return: The length of this AttributeSummary.
        :rtype: int
        """
        return self._length

    @length.setter
    def length(self, length):
        """
        Sets the length of this AttributeSummary.
        Max allowed length of the attribute value.


        :param length: The length of this AttributeSummary.
        :type: int
        """
        self._length = length

    @property
    def position(self):
        """
        Gets the position of this AttributeSummary.
        Position of the attribute in the record definition.


        :return: The position of this AttributeSummary.
        :rtype: int
        """
        return self._position

    @position.setter
    def position(self, position):
        """
        Sets the position of this AttributeSummary.
        Position of the attribute in the record definition.


        :param position: The position of this AttributeSummary.
        :type: int
        """
        self._position = position

    @property
    def precision(self):
        """
        Gets the precision of this AttributeSummary.
        Precision of the attribute value usually applies to float data type.


        :return: The precision of this AttributeSummary.
        :rtype: int
        """
        return self._precision

    @precision.setter
    def precision(self, precision):
        """
        Sets the precision of this AttributeSummary.
        Precision of the attribute value usually applies to float data type.


        :param precision: The precision of this AttributeSummary.
        :type: int
        """
        self._precision = precision

    @property
    def scale(self):
        """
        Gets the scale of this AttributeSummary.
        Scale of the attribute value usually applies to float data type.


        :return: The scale of this AttributeSummary.
        :rtype: int
        """
        return self._scale

    @scale.setter
    def scale(self, scale):
        """
        Sets the scale of this AttributeSummary.
        Scale of the attribute value usually applies to float data type.


        :param scale: The scale of this AttributeSummary.
        :type: int
        """
        self._scale = scale

    @property
    def is_nullable(self):
        """
        Gets the is_nullable of this AttributeSummary.
        Property that identifies if this attribute can be assigned null values.


        :return: The is_nullable of this AttributeSummary.
        :rtype: bool
        """
        return self._is_nullable

    @is_nullable.setter
    def is_nullable(self, is_nullable):
        """
        Sets the is_nullable of this AttributeSummary.
        Property that identifies if this attribute can be assigned null values.


        :param is_nullable: The is_nullable of this AttributeSummary.
        :type: bool
        """
        self._is_nullable = is_nullable

    @property
    def uri(self):
        """
        Gets the uri of this AttributeSummary.
        URI to the attribute instance in the API.


        :return: The uri of this AttributeSummary.
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """
        Sets the uri of this AttributeSummary.
        URI to the attribute instance in the API.


        :param uri: The uri of this AttributeSummary.
        :type: str
        """
        self._uri = uri

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this AttributeSummary.
        State of the attribute.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this AttributeSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this AttributeSummary.
        State of the attribute.


        :param lifecycle_state: The lifecycle_state of this AttributeSummary.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        Gets the time_created of this AttributeSummary.
        The date and time the attribute was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this AttributeSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this AttributeSummary.
        The date and time the attribute was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this AttributeSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def external_data_type(self):
        """
        Gets the external_data_type of this AttributeSummary.
        Data type of the attribute as defined in the external source system.


        :return: The external_data_type of this AttributeSummary.
        :rtype: str
        """
        return self._external_data_type

    @external_data_type.setter
    def external_data_type(self, external_data_type):
        """
        Sets the external_data_type of this AttributeSummary.
        Data type of the attribute as defined in the external source system.


        :param external_data_type: The external_data_type of this AttributeSummary.
        :type: str
        """
        self._external_data_type = external_data_type

    @property
    def min_collection_count(self):
        """
        Gets the min_collection_count of this AttributeSummary.
        The minimum count for the number of instances of a given type stored in this collection type attribute,applicable if this attribute is a complex type.


        :return: The min_collection_count of this AttributeSummary.
        :rtype: int
        """
        return self._min_collection_count

    @min_collection_count.setter
    def min_collection_count(self, min_collection_count):
        """
        Sets the min_collection_count of this AttributeSummary.
        The minimum count for the number of instances of a given type stored in this collection type attribute,applicable if this attribute is a complex type.


        :param min_collection_count: The min_collection_count of this AttributeSummary.
        :type: int
        """
        self._min_collection_count = min_collection_count

    @property
    def max_collection_count(self):
        """
        Gets the max_collection_count of this AttributeSummary.
        The maximum count for the number of instances of a given type stored in this collection type attribute,applicable if this attribute is a complex type.
        For type specifications in systems that specify only \"capacity\" without upper or lower bound , this property can also be used to just mean \"capacity\".
        Some examples are Varray size in Oracle , Occurs Clause in Cobol , capacity in XmlSchemaObjectCollection , maxOccurs in  Xml , maxItems in Json


        :return: The max_collection_count of this AttributeSummary.
        :rtype: int
        """
        return self._max_collection_count

    @max_collection_count.setter
    def max_collection_count(self, max_collection_count):
        """
        Sets the max_collection_count of this AttributeSummary.
        The maximum count for the number of instances of a given type stored in this collection type attribute,applicable if this attribute is a complex type.
        For type specifications in systems that specify only \"capacity\" without upper or lower bound , this property can also be used to just mean \"capacity\".
        Some examples are Varray size in Oracle , Occurs Clause in Cobol , capacity in XmlSchemaObjectCollection , maxOccurs in  Xml , maxItems in Json


        :param max_collection_count: The max_collection_count of this AttributeSummary.
        :type: int
        """
        self._max_collection_count = max_collection_count

    @property
    def datatype_entity_key(self):
        """
        Gets the datatype_entity_key of this AttributeSummary.
        Entity key that represents the datatype of this attribute , applicable if this attribute is a complex type.


        :return: The datatype_entity_key of this AttributeSummary.
        :rtype: str
        """
        return self._datatype_entity_key

    @datatype_entity_key.setter
    def datatype_entity_key(self, datatype_entity_key):
        """
        Sets the datatype_entity_key of this AttributeSummary.
        Entity key that represents the datatype of this attribute , applicable if this attribute is a complex type.


        :param datatype_entity_key: The datatype_entity_key of this AttributeSummary.
        :type: str
        """
        self._datatype_entity_key = datatype_entity_key

    @property
    def external_datatype_entity_key(self):
        """
        Gets the external_datatype_entity_key of this AttributeSummary.
        External entity key that represents the datatype of this attribute , applicable if this attribute is a complex type.


        :return: The external_datatype_entity_key of this AttributeSummary.
        :rtype: str
        """
        return self._external_datatype_entity_key

    @external_datatype_entity_key.setter
    def external_datatype_entity_key(self, external_datatype_entity_key):
        """
        Sets the external_datatype_entity_key of this AttributeSummary.
        External entity key that represents the datatype of this attribute , applicable if this attribute is a complex type.


        :param external_datatype_entity_key: The external_datatype_entity_key of this AttributeSummary.
        :type: str
        """
        self._external_datatype_entity_key = external_datatype_entity_key

    @property
    def parent_attribute_key(self):
        """
        Gets the parent_attribute_key of this AttributeSummary.
        Attribute key that represents the parent attribute of this attribute , applicable if the parent attribute is of complex datatype.


        :return: The parent_attribute_key of this AttributeSummary.
        :rtype: str
        """
        return self._parent_attribute_key

    @parent_attribute_key.setter
    def parent_attribute_key(self, parent_attribute_key):
        """
        Sets the parent_attribute_key of this AttributeSummary.
        Attribute key that represents the parent attribute of this attribute , applicable if the parent attribute is of complex datatype.


        :param parent_attribute_key: The parent_attribute_key of this AttributeSummary.
        :type: str
        """
        self._parent_attribute_key = parent_attribute_key

    @property
    def external_parent_attribute_key(self):
        """
        Gets the external_parent_attribute_key of this AttributeSummary.
        External attribute key that represents the parent attribute  of this attribute , applicable if the parent attribute is of complex type.


        :return: The external_parent_attribute_key of this AttributeSummary.
        :rtype: str
        """
        return self._external_parent_attribute_key

    @external_parent_attribute_key.setter
    def external_parent_attribute_key(self, external_parent_attribute_key):
        """
        Sets the external_parent_attribute_key of this AttributeSummary.
        External attribute key that represents the parent attribute  of this attribute , applicable if the parent attribute is of complex type.


        :param external_parent_attribute_key: The external_parent_attribute_key of this AttributeSummary.
        :type: str
        """
        self._external_parent_attribute_key = external_parent_attribute_key

    @property
    def path(self):
        """
        Gets the path of this AttributeSummary.
        Full path of the attribute.


        :return: The path of this AttributeSummary.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this AttributeSummary.
        Full path of the attribute.


        :param path: The path of this AttributeSummary.
        :type: str
        """
        self._path = path

    @property
    def custom_property_members(self):
        """
        Gets the custom_property_members of this AttributeSummary.
        The list of customized properties along with the values for this object


        :return: The custom_property_members of this AttributeSummary.
        :rtype: list[oci.data_catalog.models.CustomPropertyGetUsage]
        """
        return self._custom_property_members

    @custom_property_members.setter
    def custom_property_members(self, custom_property_members):
        """
        Sets the custom_property_members of this AttributeSummary.
        The list of customized properties along with the values for this object


        :param custom_property_members: The custom_property_members of this AttributeSummary.
        :type: list[oci.data_catalog.models.CustomPropertyGetUsage]
        """
        self._custom_property_members = custom_property_members

    @property
    def associated_rule_types(self):
        """
        Gets the associated_rule_types of this AttributeSummary.
        Rule types associated with attribute.

        Allowed values for items in this list are: "PRIMARYKEY", "FOREIGNKEY", "UNIQUEKEY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The associated_rule_types of this AttributeSummary.
        :rtype: list[str]
        """
        return self._associated_rule_types

    @associated_rule_types.setter
    def associated_rule_types(self, associated_rule_types):
        """
        Sets the associated_rule_types of this AttributeSummary.
        Rule types associated with attribute.


        :param associated_rule_types: The associated_rule_types of this AttributeSummary.
        :type: list[str]
        """
        allowed_values = ["PRIMARYKEY", "FOREIGNKEY", "UNIQUEKEY"]
        if associated_rule_types:
            associated_rule_types[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in associated_rule_types]
        self._associated_rule_types = associated_rule_types

    @property
    def is_derived_attribute(self):
        """
        Gets the is_derived_attribute of this AttributeSummary.
        Whether a column is derived or not.


        :return: The is_derived_attribute of this AttributeSummary.
        :rtype: bool
        """
        return self._is_derived_attribute

    @is_derived_attribute.setter
    def is_derived_attribute(self, is_derived_attribute):
        """
        Sets the is_derived_attribute of this AttributeSummary.
        Whether a column is derived or not.


        :param is_derived_attribute: The is_derived_attribute of this AttributeSummary.
        :type: bool
        """
        self._is_derived_attribute = is_derived_attribute

    @property
    def time_updated(self):
        """
        Gets the time_updated of this AttributeSummary.
        The last time that any change was made to the attribute. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this AttributeSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this AttributeSummary.
        The last time that any change was made to the attribute. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this AttributeSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def properties(self):
        """
        Gets the properties of this AttributeSummary.
        A map of maps that contains the properties which are specific to the attribute type. Each attribute type
        definition defines it's set of required and optional properties. The map keys are category names and the
        values are maps of property name to property value. Every property is contained inside of a category. Most
        attributes have required properties within the \"default\" category.
        Example: `{\"properties\": { \"default\": { \"key1\": \"value1\"}}}`


        :return: The properties of this AttributeSummary.
        :rtype: dict(str, dict(str, str))
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this AttributeSummary.
        A map of maps that contains the properties which are specific to the attribute type. Each attribute type
        definition defines it's set of required and optional properties. The map keys are category names and the
        values are maps of property name to property value. Every property is contained inside of a category. Most
        attributes have required properties within the \"default\" category.
        Example: `{\"properties\": { \"default\": { \"key1\": \"value1\"}}}`


        :param properties: The properties of this AttributeSummary.
        :type: dict(str, dict(str, str))
        """
        self._properties = properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ContainerImageSignatureSummary(object):
    """
    Container image signature summary.
    """

    #: A constant which can be used with the signing_algorithm property of a ContainerImageSignatureSummary.
    #: This constant has a value of "SHA_224_RSA_PKCS_PSS"
    SIGNING_ALGORITHM_SHA_224_RSA_PKCS_PSS = "SHA_224_RSA_PKCS_PSS"

    #: A constant which can be used with the signing_algorithm property of a ContainerImageSignatureSummary.
    #: This constant has a value of "SHA_256_RSA_PKCS_PSS"
    SIGNING_ALGORITHM_SHA_256_RSA_PKCS_PSS = "SHA_256_RSA_PKCS_PSS"

    #: A constant which can be used with the signing_algorithm property of a ContainerImageSignatureSummary.
    #: This constant has a value of "SHA_384_RSA_PKCS_PSS"
    SIGNING_ALGORITHM_SHA_384_RSA_PKCS_PSS = "SHA_384_RSA_PKCS_PSS"

    #: A constant which can be used with the signing_algorithm property of a ContainerImageSignatureSummary.
    #: This constant has a value of "SHA_512_RSA_PKCS_PSS"
    SIGNING_ALGORITHM_SHA_512_RSA_PKCS_PSS = "SHA_512_RSA_PKCS_PSS"

    def __init__(self, **kwargs):
        """
        Initializes a new ContainerImageSignatureSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this ContainerImageSignatureSummary.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this ContainerImageSignatureSummary.
        :type display_name: str

        :param id:
            The value to assign to the id property of this ContainerImageSignatureSummary.
        :type id: str

        :param image_id:
            The value to assign to the image_id property of this ContainerImageSignatureSummary.
        :type image_id: str

        :param kms_key_id:
            The value to assign to the kms_key_id property of this ContainerImageSignatureSummary.
        :type kms_key_id: str

        :param kms_key_version_id:
            The value to assign to the kms_key_version_id property of this ContainerImageSignatureSummary.
        :type kms_key_version_id: str

        :param message:
            The value to assign to the message property of this ContainerImageSignatureSummary.
        :type message: str

        :param signature:
            The value to assign to the signature property of this ContainerImageSignatureSummary.
        :type signature: str

        :param signing_algorithm:
            The value to assign to the signing_algorithm property of this ContainerImageSignatureSummary.
            Allowed values for this property are: "SHA_224_RSA_PKCS_PSS", "SHA_256_RSA_PKCS_PSS", "SHA_384_RSA_PKCS_PSS", "SHA_512_RSA_PKCS_PSS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type signing_algorithm: str

        :param time_created:
            The value to assign to the time_created property of this ContainerImageSignatureSummary.
        :type time_created: datetime

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'display_name': 'str',
            'id': 'str',
            'image_id': 'str',
            'kms_key_id': 'str',
            'kms_key_version_id': 'str',
            'message': 'str',
            'signature': 'str',
            'signing_algorithm': 'str',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'id': 'id',
            'image_id': 'imageId',
            'kms_key_id': 'kmsKeyId',
            'kms_key_version_id': 'kmsKeyVersionId',
            'message': 'message',
            'signature': 'signature',
            'signing_algorithm': 'signingAlgorithm',
            'time_created': 'timeCreated'
        }

        self._compartment_id = None
        self._display_name = None
        self._id = None
        self._image_id = None
        self._kms_key_id = None
        self._kms_key_version_id = None
        self._message = None
        self._signature = None
        self._signing_algorithm = None
        self._time_created = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ContainerImageSignatureSummary.
        The OCID of the compartment in which the container repository exists.


        :return: The compartment_id of this ContainerImageSignatureSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ContainerImageSignatureSummary.
        The OCID of the compartment in which the container repository exists.


        :param compartment_id: The compartment_id of this ContainerImageSignatureSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ContainerImageSignatureSummary.
        The last 10 characters of the kmsKeyId, the last 10 characters of the kmsKeyVersionId, the signingAlgorithm, and the last 10 characters of the signatureId.

        Example: `wrmz22sixa::qdwyc2ptun::SHA_256_RSA_PKCS_PSS::2vwmobasva`


        :return: The display_name of this ContainerImageSignatureSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ContainerImageSignatureSummary.
        The last 10 characters of the kmsKeyId, the last 10 characters of the kmsKeyVersionId, the signingAlgorithm, and the last 10 characters of the signatureId.

        Example: `wrmz22sixa::qdwyc2ptun::SHA_256_RSA_PKCS_PSS::2vwmobasva`


        :param display_name: The display_name of this ContainerImageSignatureSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ContainerImageSignatureSummary.
        The `OCID`__ of the container image signature.

        Example: `ocid1.containerimagesignature.oc1..exampleuniqueID`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this ContainerImageSignatureSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ContainerImageSignatureSummary.
        The `OCID`__ of the container image signature.

        Example: `ocid1.containerimagesignature.oc1..exampleuniqueID`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this ContainerImageSignatureSummary.
        :type: str
        """
        self._id = id

    @property
    def image_id(self):
        """
        **[Required]** Gets the image_id of this ContainerImageSignatureSummary.
        The `OCID`__ of the container image.

        Example: `ocid1.containerimage.oc1..exampleuniqueID`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The image_id of this ContainerImageSignatureSummary.
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """
        Sets the image_id of this ContainerImageSignatureSummary.
        The `OCID`__ of the container image.

        Example: `ocid1.containerimage.oc1..exampleuniqueID`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param image_id: The image_id of this ContainerImageSignatureSummary.
        :type: str
        """
        self._image_id = image_id

    @property
    def kms_key_id(self):
        """
        **[Required]** Gets the kms_key_id of this ContainerImageSignatureSummary.
        The `OCID`__ of the kmsKeyId used to sign the container image.

        Example: `ocid1.key.oc1..exampleuniqueID`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The kms_key_id of this ContainerImageSignatureSummary.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this ContainerImageSignatureSummary.
        The `OCID`__ of the kmsKeyId used to sign the container image.

        Example: `ocid1.key.oc1..exampleuniqueID`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param kms_key_id: The kms_key_id of this ContainerImageSignatureSummary.
        :type: str
        """
        self._kms_key_id = kms_key_id

    @property
    def kms_key_version_id(self):
        """
        **[Required]** Gets the kms_key_version_id of this ContainerImageSignatureSummary.
        The `OCID`__ of the kmsKeyVersionId used to sign the container image.

        Example: `ocid1.keyversion.oc1..exampleuniqueID`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The kms_key_version_id of this ContainerImageSignatureSummary.
        :rtype: str
        """
        return self._kms_key_version_id

    @kms_key_version_id.setter
    def kms_key_version_id(self, kms_key_version_id):
        """
        Sets the kms_key_version_id of this ContainerImageSignatureSummary.
        The `OCID`__ of the kmsKeyVersionId used to sign the container image.

        Example: `ocid1.keyversion.oc1..exampleuniqueID`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param kms_key_version_id: The kms_key_version_id of this ContainerImageSignatureSummary.
        :type: str
        """
        self._kms_key_version_id = kms_key_version_id

    @property
    def message(self):
        """
        **[Required]** Gets the message of this ContainerImageSignatureSummary.
        The base64 encoded signature payload that was signed.


        :return: The message of this ContainerImageSignatureSummary.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this ContainerImageSignatureSummary.
        The base64 encoded signature payload that was signed.


        :param message: The message of this ContainerImageSignatureSummary.
        :type: str
        """
        self._message = message

    @property
    def signature(self):
        """
        **[Required]** Gets the signature of this ContainerImageSignatureSummary.
        The signature of the message field using the kmsKeyId, the kmsKeyVersionId, and the signingAlgorithm.


        :return: The signature of this ContainerImageSignatureSummary.
        :rtype: str
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """
        Sets the signature of this ContainerImageSignatureSummary.
        The signature of the message field using the kmsKeyId, the kmsKeyVersionId, and the signingAlgorithm.


        :param signature: The signature of this ContainerImageSignatureSummary.
        :type: str
        """
        self._signature = signature

    @property
    def signing_algorithm(self):
        """
        **[Required]** Gets the signing_algorithm of this ContainerImageSignatureSummary.
        The algorithm to be used for signing. These are the only supported signing algorithms for container images.

        Allowed values for this property are: "SHA_224_RSA_PKCS_PSS", "SHA_256_RSA_PKCS_PSS", "SHA_384_RSA_PKCS_PSS", "SHA_512_RSA_PKCS_PSS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The signing_algorithm of this ContainerImageSignatureSummary.
        :rtype: str
        """
        return self._signing_algorithm

    @signing_algorithm.setter
    def signing_algorithm(self, signing_algorithm):
        """
        Sets the signing_algorithm of this ContainerImageSignatureSummary.
        The algorithm to be used for signing. These are the only supported signing algorithms for container images.


        :param signing_algorithm: The signing_algorithm of this ContainerImageSignatureSummary.
        :type: str
        """
        allowed_values = ["SHA_224_RSA_PKCS_PSS", "SHA_256_RSA_PKCS_PSS", "SHA_384_RSA_PKCS_PSS", "SHA_512_RSA_PKCS_PSS"]
        if not value_allowed_none_or_none_sentinel(signing_algorithm, allowed_values):
            signing_algorithm = 'UNKNOWN_ENUM_VALUE'
        self._signing_algorithm = signing_algorithm

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ContainerImageSignatureSummary.
        An RFC 3339 timestamp indicating when the image was created.


        :return: The time_created of this ContainerImageSignatureSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ContainerImageSignatureSummary.
        An RFC 3339 timestamp indicating when the image was created.


        :param time_created: The time_created of this ContainerImageSignatureSummary.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_item_details import CreateItemDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateLimitItemDetails(CreateItemDetails):
    """
    Reserved for future use.
    """

    #: A constant which can be used with the limit_status property of a CreateLimitItemDetails.
    #: This constant has a value of "APPROVED"
    LIMIT_STATUS_APPROVED = "APPROVED"

    #: A constant which can be used with the limit_status property of a CreateLimitItemDetails.
    #: This constant has a value of "PARTIALLY_APPROVED"
    LIMIT_STATUS_PARTIALLY_APPROVED = "PARTIALLY_APPROVED"

    #: A constant which can be used with the limit_status property of a CreateLimitItemDetails.
    #: This constant has a value of "NOT_APPROVED"
    LIMIT_STATUS_NOT_APPROVED = "NOT_APPROVED"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateLimitItemDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.cims.models.CreateLimitItemDetails.type` attribute
        of this class is ``limit`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this CreateLimitItemDetails.
        :type type: str

        :param category:
            The value to assign to the category property of this CreateLimitItemDetails.
        :type category: oci.cims.models.CreateCategoryDetails

        :param sub_category:
            The value to assign to the sub_category property of this CreateLimitItemDetails.
        :type sub_category: oci.cims.models.CreateSubCategoryDetails

        :param issue_type:
            The value to assign to the issue_type property of this CreateLimitItemDetails.
        :type issue_type: oci.cims.models.CreateIssueTypeDetails

        :param name:
            The value to assign to the name property of this CreateLimitItemDetails.
        :type name: str

        :param current_limit:
            The value to assign to the current_limit property of this CreateLimitItemDetails.
        :type current_limit: int

        :param current_usage:
            The value to assign to the current_usage property of this CreateLimitItemDetails.
        :type current_usage: int

        :param requested_limit:
            The value to assign to the requested_limit property of this CreateLimitItemDetails.
        :type requested_limit: int

        :param limit_status:
            The value to assign to the limit_status property of this CreateLimitItemDetails.
            Allowed values for this property are: "APPROVED", "PARTIALLY_APPROVED", "NOT_APPROVED"
        :type limit_status: str

        """
        self.swagger_types = {
            'type': 'str',
            'category': 'CreateCategoryDetails',
            'sub_category': 'CreateSubCategoryDetails',
            'issue_type': 'CreateIssueTypeDetails',
            'name': 'str',
            'current_limit': 'int',
            'current_usage': 'int',
            'requested_limit': 'int',
            'limit_status': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'category': 'category',
            'sub_category': 'subCategory',
            'issue_type': 'issueType',
            'name': 'name',
            'current_limit': 'currentLimit',
            'current_usage': 'currentUsage',
            'requested_limit': 'requestedLimit',
            'limit_status': 'limitStatus'
        }

        self._type = None
        self._category = None
        self._sub_category = None
        self._issue_type = None
        self._name = None
        self._current_limit = None
        self._current_usage = None
        self._requested_limit = None
        self._limit_status = None
        self._type = 'limit'

    @property
    def current_limit(self):
        """
        Gets the current_limit of this CreateLimitItemDetails.
        The limit of the resource currently available.


        :return: The current_limit of this CreateLimitItemDetails.
        :rtype: int
        """
        return self._current_limit

    @current_limit.setter
    def current_limit(self, current_limit):
        """
        Sets the current_limit of this CreateLimitItemDetails.
        The limit of the resource currently available.


        :param current_limit: The current_limit of this CreateLimitItemDetails.
        :type: int
        """
        self._current_limit = current_limit

    @property
    def current_usage(self):
        """
        Gets the current_usage of this CreateLimitItemDetails.
        The current usage of the resource.


        :return: The current_usage of this CreateLimitItemDetails.
        :rtype: int
        """
        return self._current_usage

    @current_usage.setter
    def current_usage(self, current_usage):
        """
        Sets the current_usage of this CreateLimitItemDetails.
        The current usage of the resource.


        :param current_usage: The current_usage of this CreateLimitItemDetails.
        :type: int
        """
        self._current_usage = current_usage

    @property
    def requested_limit(self):
        """
        Gets the requested_limit of this CreateLimitItemDetails.
        Reserved for future use.


        :return: The requested_limit of this CreateLimitItemDetails.
        :rtype: int
        """
        return self._requested_limit

    @requested_limit.setter
    def requested_limit(self, requested_limit):
        """
        Sets the requested_limit of this CreateLimitItemDetails.
        Reserved for future use.


        :param requested_limit: The requested_limit of this CreateLimitItemDetails.
        :type: int
        """
        self._requested_limit = requested_limit

    @property
    def limit_status(self):
        """
        Gets the limit_status of this CreateLimitItemDetails.
        The current status of the request.

        Allowed values for this property are: "APPROVED", "PARTIALLY_APPROVED", "NOT_APPROVED"


        :return: The limit_status of this CreateLimitItemDetails.
        :rtype: str
        """
        return self._limit_status

    @limit_status.setter
    def limit_status(self, limit_status):
        """
        Sets the limit_status of this CreateLimitItemDetails.
        The current status of the request.


        :param limit_status: The limit_status of this CreateLimitItemDetails.
        :type: str
        """
        allowed_values = ["APPROVED", "PARTIALLY_APPROVED", "NOT_APPROVED"]
        if not value_allowed_none_or_none_sentinel(limit_status, allowed_values):
            raise ValueError(
                "Invalid value for `limit_status`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._limit_status = limit_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TaxSummary(object):
    """
    Tax implication that current tenant may be eligible while using specific listing
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TaxSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param code:
            The value to assign to the code property of this TaxSummary.
        :type code: str

        :param name:
            The value to assign to the name property of this TaxSummary.
        :type name: str

        :param country:
            The value to assign to the country property of this TaxSummary.
        :type country: str

        :param url:
            The value to assign to the url property of this TaxSummary.
        :type url: str

        """
        self.swagger_types = {
            'code': 'str',
            'name': 'str',
            'country': 'str',
            'url': 'str'
        }

        self.attribute_map = {
            'code': 'code',
            'name': 'name',
            'country': 'country',
            'url': 'url'
        }

        self._code = None
        self._name = None
        self._country = None
        self._url = None

    @property
    def code(self):
        """
        **[Required]** Gets the code of this TaxSummary.
        Unique code for the tax.


        :return: The code of this TaxSummary.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """
        Sets the code of this TaxSummary.
        Unique code for the tax.


        :param code: The code of this TaxSummary.
        :type: str
        """
        self._code = code

    @property
    def name(self):
        """
        Gets the name of this TaxSummary.
        Name of the tax code.


        :return: The name of this TaxSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TaxSummary.
        Name of the tax code.


        :param name: The name of this TaxSummary.
        :type: str
        """
        self._name = name

    @property
    def country(self):
        """
        Gets the country of this TaxSummary.
        Country, which imposes the tax.


        :return: The country of this TaxSummary.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this TaxSummary.
        Country, which imposes the tax.


        :param country: The country of this TaxSummary.
        :type: str
        """
        self._country = country

    @property
    def url(self):
        """
        Gets the url of this TaxSummary.
        The URL with more details about this tax.


        :return: The url of this TaxSummary.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """
        Sets the url of this TaxSummary.
        The URL with more details about this tax.


        :param url: The url of this TaxSummary.
        :type: str
        """
        self._url = url

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .database_configuration_summary import DatabaseConfigurationSummary
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class EmManagedExternalDatabaseConfigurationSummary(DatabaseConfigurationSummary):
    """
    Configuration summary of a EM Managed External database.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new EmManagedExternalDatabaseConfigurationSummary object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.EmManagedExternalDatabaseConfigurationSummary.entity_source` attribute
        of this class is ``EM_MANAGED_EXTERNAL_DATABASE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param database_insight_id:
            The value to assign to the database_insight_id property of this EmManagedExternalDatabaseConfigurationSummary.
        :type database_insight_id: str

        :param entity_source:
            The value to assign to the entity_source property of this EmManagedExternalDatabaseConfigurationSummary.
            Allowed values for this property are: "AUTONOMOUS_DATABASE", "EM_MANAGED_EXTERNAL_DATABASE", "MACS_MANAGED_EXTERNAL_DATABASE"
        :type entity_source: str

        :param compartment_id:
            The value to assign to the compartment_id property of this EmManagedExternalDatabaseConfigurationSummary.
        :type compartment_id: str

        :param database_name:
            The value to assign to the database_name property of this EmManagedExternalDatabaseConfigurationSummary.
        :type database_name: str

        :param database_display_name:
            The value to assign to the database_display_name property of this EmManagedExternalDatabaseConfigurationSummary.
        :type database_display_name: str

        :param database_type:
            The value to assign to the database_type property of this EmManagedExternalDatabaseConfigurationSummary.
        :type database_type: str

        :param database_version:
            The value to assign to the database_version property of this EmManagedExternalDatabaseConfigurationSummary.
        :type database_version: str

        :param defined_tags:
            The value to assign to the defined_tags property of this EmManagedExternalDatabaseConfigurationSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this EmManagedExternalDatabaseConfigurationSummary.
        :type freeform_tags: dict(str, str)

        :param processor_count:
            The value to assign to the processor_count property of this EmManagedExternalDatabaseConfigurationSummary.
        :type processor_count: int

        :param enterprise_manager_identifier:
            The value to assign to the enterprise_manager_identifier property of this EmManagedExternalDatabaseConfigurationSummary.
        :type enterprise_manager_identifier: str

        :param enterprise_manager_bridge_id:
            The value to assign to the enterprise_manager_bridge_id property of this EmManagedExternalDatabaseConfigurationSummary.
        :type enterprise_manager_bridge_id: str

        :param instances:
            The value to assign to the instances property of this EmManagedExternalDatabaseConfigurationSummary.
        :type instances: list[oci.opsi.models.HostInstanceMap]

        """
        self.swagger_types = {
            'database_insight_id': 'str',
            'entity_source': 'str',
            'compartment_id': 'str',
            'database_name': 'str',
            'database_display_name': 'str',
            'database_type': 'str',
            'database_version': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)',
            'processor_count': 'int',
            'enterprise_manager_identifier': 'str',
            'enterprise_manager_bridge_id': 'str',
            'instances': 'list[HostInstanceMap]'
        }

        self.attribute_map = {
            'database_insight_id': 'databaseInsightId',
            'entity_source': 'entitySource',
            'compartment_id': 'compartmentId',
            'database_name': 'databaseName',
            'database_display_name': 'databaseDisplayName',
            'database_type': 'databaseType',
            'database_version': 'databaseVersion',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags',
            'processor_count': 'processorCount',
            'enterprise_manager_identifier': 'enterpriseManagerIdentifier',
            'enterprise_manager_bridge_id': 'enterpriseManagerBridgeId',
            'instances': 'instances'
        }

        self._database_insight_id = None
        self._entity_source = None
        self._compartment_id = None
        self._database_name = None
        self._database_display_name = None
        self._database_type = None
        self._database_version = None
        self._defined_tags = None
        self._freeform_tags = None
        self._processor_count = None
        self._enterprise_manager_identifier = None
        self._enterprise_manager_bridge_id = None
        self._instances = None
        self._entity_source = 'EM_MANAGED_EXTERNAL_DATABASE'

    @property
    def enterprise_manager_identifier(self):
        """
        **[Required]** Gets the enterprise_manager_identifier of this EmManagedExternalDatabaseConfigurationSummary.
        Enterprise Manager Unique Identifier


        :return: The enterprise_manager_identifier of this EmManagedExternalDatabaseConfigurationSummary.
        :rtype: str
        """
        return self._enterprise_manager_identifier

    @enterprise_manager_identifier.setter
    def enterprise_manager_identifier(self, enterprise_manager_identifier):
        """
        Sets the enterprise_manager_identifier of this EmManagedExternalDatabaseConfigurationSummary.
        Enterprise Manager Unique Identifier


        :param enterprise_manager_identifier: The enterprise_manager_identifier of this EmManagedExternalDatabaseConfigurationSummary.
        :type: str
        """
        self._enterprise_manager_identifier = enterprise_manager_identifier

    @property
    def enterprise_manager_bridge_id(self):
        """
        **[Required]** Gets the enterprise_manager_bridge_id of this EmManagedExternalDatabaseConfigurationSummary.
        OPSI Enterprise Manager Bridge OCID


        :return: The enterprise_manager_bridge_id of this EmManagedExternalDatabaseConfigurationSummary.
        :rtype: str
        """
        return self._enterprise_manager_bridge_id

    @enterprise_manager_bridge_id.setter
    def enterprise_manager_bridge_id(self, enterprise_manager_bridge_id):
        """
        Sets the enterprise_manager_bridge_id of this EmManagedExternalDatabaseConfigurationSummary.
        OPSI Enterprise Manager Bridge OCID


        :param enterprise_manager_bridge_id: The enterprise_manager_bridge_id of this EmManagedExternalDatabaseConfigurationSummary.
        :type: str
        """
        self._enterprise_manager_bridge_id = enterprise_manager_bridge_id

    @property
    def instances(self):
        """
        **[Required]** Gets the instances of this EmManagedExternalDatabaseConfigurationSummary.
        Array of hostname and instance name.


        :return: The instances of this EmManagedExternalDatabaseConfigurationSummary.
        :rtype: list[oci.opsi.models.HostInstanceMap]
        """
        return self._instances

    @instances.setter
    def instances(self, instances):
        """
        Sets the instances of this EmManagedExternalDatabaseConfigurationSummary.
        Array of hostname and instance name.


        :param instances: The instances of this EmManagedExternalDatabaseConfigurationSummary.
        :type: list[oci.opsi.models.HostInstanceMap]
        """
        self._instances = instances

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateVmClusterDetails(object):
    """
    Details for updating the VM cluster. Applies to Exadata Cloud@Customer instances only.
    For details on updating a cloud VM cluster in an Exadata Cloud Service instance, see :func:`update_cloud_vm_cluster_details`
    """

    #: A constant which can be used with the license_model property of a UpdateVmClusterDetails.
    #: This constant has a value of "LICENSE_INCLUDED"
    LICENSE_MODEL_LICENSE_INCLUDED = "LICENSE_INCLUDED"

    #: A constant which can be used with the license_model property of a UpdateVmClusterDetails.
    #: This constant has a value of "BRING_YOUR_OWN_LICENSE"
    LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = "BRING_YOUR_OWN_LICENSE"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateVmClusterDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cpu_core_count:
            The value to assign to the cpu_core_count property of this UpdateVmClusterDetails.
        :type cpu_core_count: int

        :param memory_size_in_gbs:
            The value to assign to the memory_size_in_gbs property of this UpdateVmClusterDetails.
        :type memory_size_in_gbs: int

        :param db_node_storage_size_in_gbs:
            The value to assign to the db_node_storage_size_in_gbs property of this UpdateVmClusterDetails.
        :type db_node_storage_size_in_gbs: int

        :param data_storage_size_in_tbs:
            The value to assign to the data_storage_size_in_tbs property of this UpdateVmClusterDetails.
        :type data_storage_size_in_tbs: float

        :param license_model:
            The value to assign to the license_model property of this UpdateVmClusterDetails.
            Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"
        :type license_model: str

        :param ssh_public_keys:
            The value to assign to the ssh_public_keys property of this UpdateVmClusterDetails.
        :type ssh_public_keys: list[str]

        :param version:
            The value to assign to the version property of this UpdateVmClusterDetails.
        :type version: oci.database.models.PatchDetails

        :param update_details:
            The value to assign to the update_details property of this UpdateVmClusterDetails.
        :type update_details: oci.database.models.VmClusterUpdateDetails

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateVmClusterDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateVmClusterDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'cpu_core_count': 'int',
            'memory_size_in_gbs': 'int',
            'db_node_storage_size_in_gbs': 'int',
            'data_storage_size_in_tbs': 'float',
            'license_model': 'str',
            'ssh_public_keys': 'list[str]',
            'version': 'PatchDetails',
            'update_details': 'VmClusterUpdateDetails',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'cpu_core_count': 'cpuCoreCount',
            'memory_size_in_gbs': 'memorySizeInGBs',
            'db_node_storage_size_in_gbs': 'dbNodeStorageSizeInGBs',
            'data_storage_size_in_tbs': 'dataStorageSizeInTBs',
            'license_model': 'licenseModel',
            'ssh_public_keys': 'sshPublicKeys',
            'version': 'version',
            'update_details': 'updateDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._cpu_core_count = None
        self._memory_size_in_gbs = None
        self._db_node_storage_size_in_gbs = None
        self._data_storage_size_in_tbs = None
        self._license_model = None
        self._ssh_public_keys = None
        self._version = None
        self._update_details = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def cpu_core_count(self):
        """
        Gets the cpu_core_count of this UpdateVmClusterDetails.
        The number of CPU cores to enable for the VM cluster.


        :return: The cpu_core_count of this UpdateVmClusterDetails.
        :rtype: int
        """
        return self._cpu_core_count

    @cpu_core_count.setter
    def cpu_core_count(self, cpu_core_count):
        """
        Sets the cpu_core_count of this UpdateVmClusterDetails.
        The number of CPU cores to enable for the VM cluster.


        :param cpu_core_count: The cpu_core_count of this UpdateVmClusterDetails.
        :type: int
        """
        self._cpu_core_count = cpu_core_count

    @property
    def memory_size_in_gbs(self):
        """
        Gets the memory_size_in_gbs of this UpdateVmClusterDetails.
        The memory to be allocated in GBs.


        :return: The memory_size_in_gbs of this UpdateVmClusterDetails.
        :rtype: int
        """
        return self._memory_size_in_gbs

    @memory_size_in_gbs.setter
    def memory_size_in_gbs(self, memory_size_in_gbs):
        """
        Sets the memory_size_in_gbs of this UpdateVmClusterDetails.
        The memory to be allocated in GBs.


        :param memory_size_in_gbs: The memory_size_in_gbs of this UpdateVmClusterDetails.
        :type: int
        """
        self._memory_size_in_gbs = memory_size_in_gbs

    @property
    def db_node_storage_size_in_gbs(self):
        """
        Gets the db_node_storage_size_in_gbs of this UpdateVmClusterDetails.
        The local node storage to be allocated in GBs.


        :return: The db_node_storage_size_in_gbs of this UpdateVmClusterDetails.
        :rtype: int
        """
        return self._db_node_storage_size_in_gbs

    @db_node_storage_size_in_gbs.setter
    def db_node_storage_size_in_gbs(self, db_node_storage_size_in_gbs):
        """
        Sets the db_node_storage_size_in_gbs of this UpdateVmClusterDetails.
        The local node storage to be allocated in GBs.


        :param db_node_storage_size_in_gbs: The db_node_storage_size_in_gbs of this UpdateVmClusterDetails.
        :type: int
        """
        self._db_node_storage_size_in_gbs = db_node_storage_size_in_gbs

    @property
    def data_storage_size_in_tbs(self):
        """
        Gets the data_storage_size_in_tbs of this UpdateVmClusterDetails.
        The data disk group size to be allocated in TBs.


        :return: The data_storage_size_in_tbs of this UpdateVmClusterDetails.
        :rtype: float
        """
        return self._data_storage_size_in_tbs

    @data_storage_size_in_tbs.setter
    def data_storage_size_in_tbs(self, data_storage_size_in_tbs):
        """
        Sets the data_storage_size_in_tbs of this UpdateVmClusterDetails.
        The data disk group size to be allocated in TBs.


        :param data_storage_size_in_tbs: The data_storage_size_in_tbs of this UpdateVmClusterDetails.
        :type: float
        """
        self._data_storage_size_in_tbs = data_storage_size_in_tbs

    @property
    def license_model(self):
        """
        Gets the license_model of this UpdateVmClusterDetails.
        The Oracle license model that applies to the VM cluster. The default is BRING_YOUR_OWN_LICENSE.

        Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"


        :return: The license_model of this UpdateVmClusterDetails.
        :rtype: str
        """
        return self._license_model

    @license_model.setter
    def license_model(self, license_model):
        """
        Sets the license_model of this UpdateVmClusterDetails.
        The Oracle license model that applies to the VM cluster. The default is BRING_YOUR_OWN_LICENSE.


        :param license_model: The license_model of this UpdateVmClusterDetails.
        :type: str
        """
        allowed_values = ["LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"]
        if not value_allowed_none_or_none_sentinel(license_model, allowed_values):
            raise ValueError(
                "Invalid value for `license_model`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._license_model = license_model

    @property
    def ssh_public_keys(self):
        """
        Gets the ssh_public_keys of this UpdateVmClusterDetails.
        The public key portion of one or more key pairs used for SSH access to the VM cluster.


        :return: The ssh_public_keys of this UpdateVmClusterDetails.
        :rtype: list[str]
        """
        return self._ssh_public_keys

    @ssh_public_keys.setter
    def ssh_public_keys(self, ssh_public_keys):
        """
        Sets the ssh_public_keys of this UpdateVmClusterDetails.
        The public key portion of one or more key pairs used for SSH access to the VM cluster.


        :param ssh_public_keys: The ssh_public_keys of this UpdateVmClusterDetails.
        :type: list[str]
        """
        self._ssh_public_keys = ssh_public_keys

    @property
    def version(self):
        """
        Gets the version of this UpdateVmClusterDetails.

        :return: The version of this UpdateVmClusterDetails.
        :rtype: oci.database.models.PatchDetails
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this UpdateVmClusterDetails.

        :param version: The version of this UpdateVmClusterDetails.
        :type: oci.database.models.PatchDetails
        """
        self._version = version

    @property
    def update_details(self):
        """
        Gets the update_details of this UpdateVmClusterDetails.

        :return: The update_details of this UpdateVmClusterDetails.
        :rtype: oci.database.models.VmClusterUpdateDetails
        """
        return self._update_details

    @update_details.setter
    def update_details(self, update_details):
        """
        Sets the update_details of this UpdateVmClusterDetails.

        :param update_details: The update_details of this UpdateVmClusterDetails.
        :type: oci.database.models.VmClusterUpdateDetails
        """
        self._update_details = update_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateVmClusterDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateVmClusterDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateVmClusterDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateVmClusterDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateVmClusterDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateVmClusterDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateVmClusterDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateVmClusterDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from . import auth_utils
from .security_token_container import SecurityTokenContainer
from cryptography.hazmat.primitives.serialization import Encoding, PublicFormat
from cryptography.hazmat.primitives.hashes import SHA1

from oci._vendor import requests

import oci.retry
import oci.signer
import threading


class X509FederationClient(object):
    REQUIRED_INIT_KWARGS = [
        'federation_endpoint',
        'tenancy_id',
        'session_key_supplier',
        'leaf_certificate_retriever'
    ]

    def __init__(self, **kwargs):
        """
        A client which can be used to retrieve a token from Auth Service. It needs the following supplied to it:

            - The endpoint for Auth Service
            - Our tenancy OCID
            - A session key supplier so that we can send its public key as part of the token request. The private key
            in the session key supplier should be used to sign all requests made with the token
            - The certificate (via leaf_certificate_retriever) which will be used to sign the requests to Auth Service.

        Optionally, intermediate certificates (if present) can be supplied as part of the request to Auth Service.

        The client has knowledge of its last requested token and can re-request the token if it is expired (otherwise
        it will vend the last requested token if it is not expired).

        :param str federation_endpoint:
            The Auth Service endpoint from which to retrieve the token.

        :param str tenancy_id:
            The OCID of the tenancy whose resources will be interacted with by users of the token.

        :param SessionKeySupplier session_key_supplier:
            A SessionKeySupplier that can vend a public and private key. The public key will be sent as part of the token
            request and the private key should be used to sign all requests made with the token vended by this client.

        :param CertificateRetriever leaf_certificate_retriever:
            The certificate which will be used to sign requests to Auth Service.

        :param list[CertificateRetriever] intermediate_certificate_retrievers: (optional)
            A list of retrievers which can be used to fetch intermediate certificates which can be sent as part of the Auth Service request. This is an optional parameter

        :param cert_bundle_verify: (optional)
            If we need a specific cert bundle in order to perform verification against the federation endpoint, this parameter is the path to that bundle. Alternatively,
            False can be passed to disable verification.
        :type cert_bundle_verify: str or Boolean

        :param obj retry_strategy: (optional)
            A retry strategy to apply to calls made by this client. This should be one of the strategies available in
            the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` is also available and
            will be used if no explicit retry strategy is specified.

            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
        """

        kwarg_keys = kwargs.keys()
        missing_keys = []

        for required in self.REQUIRED_INIT_KWARGS:
            if required not in kwarg_keys:
                missing_keys.append(required)
            elif not kwargs[required]:
                missing_keys.append(required)

        if missing_keys:
            raise TypeError('The following required arguments were not provided: {}'.format(', '.join(missing_keys)))

        self.federation_endpoint = kwargs['federation_endpoint']
        self.tenancy_id = kwargs['tenancy_id']
        self.session_key_supplier = kwargs['session_key_supplier']
        self.leaf_certificate_retriever = kwargs['leaf_certificate_retriever']

        # The default (instance principal) purpose is None
        self.purpose = None
        if 'purpose' in kwargs and kwargs['purpose'] is not None:
            self.purpose = kwargs['purpose']

        if 'intermediate_certificate_retrievers' in kwargs and kwargs['intermediate_certificate_retrievers']:
            self.intermediate_certificate_retrievers = kwargs['intermediate_certificate_retrievers']
        else:
            self.intermediate_certificate_retrievers = []

        self.cert_bundle_verify = kwargs.get('cert_bundle_verify', None)
        self._refresh_lock = threading.Lock()

        retry_strategy = kwargs.get('retry_strategy', None)
        if retry_strategy:
            self.retry_strategy = retry_strategy
        else:
            self.retry_strategy = oci.retry.DEFAULT_RETRY_STRATEGY

        self.requests_session = requests.Session()

    def refresh_security_token(self):
        return self._refresh_security_token_inner()

    def get_security_token(self):
        if hasattr(self, 'security_token'):
            if self.security_token.valid_with_jitter():
                return self.security_token.security_token

        return self._refresh_security_token_inner()

    def _refresh_security_token_inner(self):
        self._refresh_lock.acquire()
        try:
            self.session_key_supplier.refresh()
            self.leaf_certificate_retriever.refresh()
            # for the default (instance principal) purpose, verify tenancy id matches
            if self.purpose is None:
                updated_tenancy_id = auth_utils.get_tenancy_id_from_certificate(self.leaf_certificate_retriever.get_certificate_as_certificate())
                if updated_tenancy_id != self.tenancy_id:
                    raise RuntimeError('Unexpected update of tenancy OCID in the leaf certificate. Previous tenancy: {}, Updated: {}'.format(self.tenancy_id, updated_tenancy_id))

            for retriever in self.intermediate_certificate_retrievers:
                retriever.refresh()

            self.retry_strategy.make_retrying_call(self._get_security_token_from_auth_service)
            return self.security_token.security_token
        finally:
            self._refresh_lock.release()

    def _get_security_token_from_auth_service(self):
        request_payload = {
            'certificate': auth_utils.sanitize_certificate_string(self.leaf_certificate_retriever.get_certificate_raw()),
            'publicKey': auth_utils.sanitize_certificate_string(self.session_key_supplier.get_key_pair()['public'].public_bytes(Encoding.PEM, PublicFormat.SubjectPublicKeyInfo))
        }
        # The default (instance principal) purpose is None
        if self.purpose is not None:
            request_payload['purpose'] = self.purpose

        if self.intermediate_certificate_retrievers:
            retrieved_certs = []
            for retriever in self.intermediate_certificate_retrievers:
                retrieved_certs.append(auth_utils.sanitize_certificate_string(retriever.get_certificate_raw()))

            request_payload['intermediateCertificates'] = retrieved_certs

        certificate = self.leaf_certificate_retriever.get_certificate_as_certificate()
        fingerprint = ":".join("{:02X}".format(ch) for ch in bytearray(certificate.fingerprint(SHA1())))
        signer = AuthTokenRequestSigner(self.tenancy_id, fingerprint, self.leaf_certificate_retriever)

        response = self.requests_session.post(self.federation_endpoint, json=request_payload, auth=signer, verify=self.cert_bundle_verify, timeout=(10, 60))

        parsed_response = None
        try:
            parsed_response = response.json()
        except ValueError:
            error_text = 'Unable to parse response from auth service ({}): {}'.format(self.federation_endpoint, response.text)

            # If the response was a 2xx but unparseable, raise it straight away because it implies a potential service issue. If
            # we have a non-2xx but it is not parseable that is a more ambiguous scenario (e.g. could have been an issue with a
            # proxy or LB and those generally won't emit a JSON response) so throw it out a ServiceError so it can fall into
            # retry logic (depending on the error code)
            if response.ok:
                raise RuntimeError(error_text)
            else:
                raise oci.exceptions.ServiceError(
                    response.status_code,
                    response.reason,
                    response.headers,
                    error_text
                )

        if not response.ok:
            raise oci.exceptions.ServiceError(
                response.status_code,
                parsed_response.get('code'),
                response.headers,
                parsed_response.get('message')
            )
        else:
            if 'token' in parsed_response:
                self.security_token = SecurityTokenContainer(self.session_key_supplier, response.json()['token'])
            else:
                raise RuntimeError('Could not find token in response from auth service ({}): {}'.format(self.federation_endpoint, parsed_response))


class AuthTokenRequestSigner(oci.signer.AbstractBaseSigner):
    """
    A signer intended for X509FederationClient's use to request a token from Auth Service. Not intended for general use.
    """

    def __init__(self, tenancy_id, fingerprint, private_key_certificate_retriever):
        self.api_key = '{}/fed-x509/{}'.format(tenancy_id, fingerprint)
        self.private_key_certificate_retriever = private_key_certificate_retriever

        generic_headers = ["date", "(request-target)"]
        body_headers = ["content-length", "content-type", "x-content-sha256"]
        self.create_signers(self.api_key, self.private_key_certificate_retriever.get_private_key(), generic_headers, body_headers)



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExecutionLogPolicy(object):
    """
    Configures the logging policies for the execution logs of an API Deployment.
    """

    #: A constant which can be used with the log_level property of a ExecutionLogPolicy.
    #: This constant has a value of "INFO"
    LOG_LEVEL_INFO = "INFO"

    #: A constant which can be used with the log_level property of a ExecutionLogPolicy.
    #: This constant has a value of "WARN"
    LOG_LEVEL_WARN = "WARN"

    #: A constant which can be used with the log_level property of a ExecutionLogPolicy.
    #: This constant has a value of "ERROR"
    LOG_LEVEL_ERROR = "ERROR"

    def __init__(self, **kwargs):
        """
        Initializes a new ExecutionLogPolicy object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_enabled:
            The value to assign to the is_enabled property of this ExecutionLogPolicy.
        :type is_enabled: bool

        :param log_level:
            The value to assign to the log_level property of this ExecutionLogPolicy.
            Allowed values for this property are: "INFO", "WARN", "ERROR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type log_level: str

        """
        self.swagger_types = {
            'is_enabled': 'bool',
            'log_level': 'str'
        }

        self.attribute_map = {
            'is_enabled': 'isEnabled',
            'log_level': 'logLevel'
        }

        self._is_enabled = None
        self._log_level = None

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this ExecutionLogPolicy.
        Enables pushing of execution logs to the legacy OCI Object Storage log archival bucket.

        Oracle recommends using the OCI Logging service to enable, retrieve, and query execution logs
        for an API Deployment. If there is an active log object for the API Deployment and its
        category is set to 'execution' in OCI Logging service, the logs will not be uploaded to the legacy
        OCI Object Storage log archival bucket.

        Please note that the functionality to push to the legacy OCI Object Storage log
        archival bucket has been deprecated and will be removed in the future.


        :return: The is_enabled of this ExecutionLogPolicy.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this ExecutionLogPolicy.
        Enables pushing of execution logs to the legacy OCI Object Storage log archival bucket.

        Oracle recommends using the OCI Logging service to enable, retrieve, and query execution logs
        for an API Deployment. If there is an active log object for the API Deployment and its
        category is set to 'execution' in OCI Logging service, the logs will not be uploaded to the legacy
        OCI Object Storage log archival bucket.

        Please note that the functionality to push to the legacy OCI Object Storage log
        archival bucket has been deprecated and will be removed in the future.


        :param is_enabled: The is_enabled of this ExecutionLogPolicy.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def log_level(self):
        """
        Gets the log_level of this ExecutionLogPolicy.
        Specifies the log level used to control logging output of execution logs.
        Enabling logging at a given level also enables logging at all higher levels.

        Allowed values for this property are: "INFO", "WARN", "ERROR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The log_level of this ExecutionLogPolicy.
        :rtype: str
        """
        return self._log_level

    @log_level.setter
    def log_level(self, log_level):
        """
        Sets the log_level of this ExecutionLogPolicy.
        Specifies the log level used to control logging output of execution logs.
        Enabling logging at a given level also enables logging at all higher levels.


        :param log_level: The log_level of this ExecutionLogPolicy.
        :type: str
        """
        allowed_values = ["INFO", "WARN", "ERROR"]
        if not value_allowed_none_or_none_sentinel(log_level, allowed_values):
            log_level = 'UNKNOWN_ENUM_VALUE'
        self._log_level = log_level

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Row(object):
    """
    The result of GetRow.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Row object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param value:
            The value to assign to the value property of this Row.
        :type value: dict(str, object)

        :param time_of_expiration:
            The value to assign to the time_of_expiration property of this Row.
        :type time_of_expiration: datetime

        :param usage:
            The value to assign to the usage property of this Row.
        :type usage: oci.nosql.models.RequestUsage

        """
        self.swagger_types = {
            'value': 'dict(str, object)',
            'time_of_expiration': 'datetime',
            'usage': 'RequestUsage'
        }

        self.attribute_map = {
            'value': 'value',
            'time_of_expiration': 'timeOfExpiration',
            'usage': 'usage'
        }

        self._value = None
        self._time_of_expiration = None
        self._usage = None

    @property
    def value(self):
        """
        Gets the value of this Row.
        The map of values from a row.


        :return: The value of this Row.
        :rtype: dict(str, object)
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this Row.
        The map of values from a row.


        :param value: The value of this Row.
        :type: dict(str, object)
        """
        self._value = value

    @property
    def time_of_expiration(self):
        """
        Gets the time_of_expiration of this Row.
        The expiration time of the row. A zero value indicates that
        the row does not expire. An RFC3339 formatted datetime
        string.


        :return: The time_of_expiration of this Row.
        :rtype: datetime
        """
        return self._time_of_expiration

    @time_of_expiration.setter
    def time_of_expiration(self, time_of_expiration):
        """
        Sets the time_of_expiration of this Row.
        The expiration time of the row. A zero value indicates that
        the row does not expire. An RFC3339 formatted datetime
        string.


        :param time_of_expiration: The time_of_expiration of this Row.
        :type: datetime
        """
        self._time_of_expiration = time_of_expiration

    @property
    def usage(self):
        """
        Gets the usage of this Row.

        :return: The usage of this Row.
        :rtype: oci.nosql.models.RequestUsage
        """
        return self._usage

    @usage.setter
    def usage(self, usage):
        """
        Sets the usage of this Row.

        :param usage: The usage of this Row.
        :type: oci.nosql.models.RequestUsage
        """
        self._usage = usage

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ImportableEnterpriseManagerEntity(object):
    """
    An Enterprise Manager entity that can be imported into Operations Insights.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ImportableEnterpriseManagerEntity object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param enterprise_manager_identifier:
            The value to assign to the enterprise_manager_identifier property of this ImportableEnterpriseManagerEntity.
        :type enterprise_manager_identifier: str

        :param enterprise_manager_entity_name:
            The value to assign to the enterprise_manager_entity_name property of this ImportableEnterpriseManagerEntity.
        :type enterprise_manager_entity_name: str

        :param enterprise_manager_entity_type:
            The value to assign to the enterprise_manager_entity_type property of this ImportableEnterpriseManagerEntity.
        :type enterprise_manager_entity_type: str

        :param enterprise_manager_entity_identifier:
            The value to assign to the enterprise_manager_entity_identifier property of this ImportableEnterpriseManagerEntity.
        :type enterprise_manager_entity_identifier: str

        :param opsi_entity_type:
            The value to assign to the opsi_entity_type property of this ImportableEnterpriseManagerEntity.
        :type opsi_entity_type: str

        """
        self.swagger_types = {
            'enterprise_manager_identifier': 'str',
            'enterprise_manager_entity_name': 'str',
            'enterprise_manager_entity_type': 'str',
            'enterprise_manager_entity_identifier': 'str',
            'opsi_entity_type': 'str'
        }

        self.attribute_map = {
            'enterprise_manager_identifier': 'enterpriseManagerIdentifier',
            'enterprise_manager_entity_name': 'enterpriseManagerEntityName',
            'enterprise_manager_entity_type': 'enterpriseManagerEntityType',
            'enterprise_manager_entity_identifier': 'enterpriseManagerEntityIdentifier',
            'opsi_entity_type': 'opsiEntityType'
        }

        self._enterprise_manager_identifier = None
        self._enterprise_manager_entity_name = None
        self._enterprise_manager_entity_type = None
        self._enterprise_manager_entity_identifier = None
        self._opsi_entity_type = None

    @property
    def enterprise_manager_identifier(self):
        """
        **[Required]** Gets the enterprise_manager_identifier of this ImportableEnterpriseManagerEntity.
        Enterprise Manager Unique Identifier


        :return: The enterprise_manager_identifier of this ImportableEnterpriseManagerEntity.
        :rtype: str
        """
        return self._enterprise_manager_identifier

    @enterprise_manager_identifier.setter
    def enterprise_manager_identifier(self, enterprise_manager_identifier):
        """
        Sets the enterprise_manager_identifier of this ImportableEnterpriseManagerEntity.
        Enterprise Manager Unique Identifier


        :param enterprise_manager_identifier: The enterprise_manager_identifier of this ImportableEnterpriseManagerEntity.
        :type: str
        """
        self._enterprise_manager_identifier = enterprise_manager_identifier

    @property
    def enterprise_manager_entity_name(self):
        """
        **[Required]** Gets the enterprise_manager_entity_name of this ImportableEnterpriseManagerEntity.
        Enterprise Manager Entity Name


        :return: The enterprise_manager_entity_name of this ImportableEnterpriseManagerEntity.
        :rtype: str
        """
        return self._enterprise_manager_entity_name

    @enterprise_manager_entity_name.setter
    def enterprise_manager_entity_name(self, enterprise_manager_entity_name):
        """
        Sets the enterprise_manager_entity_name of this ImportableEnterpriseManagerEntity.
        Enterprise Manager Entity Name


        :param enterprise_manager_entity_name: The enterprise_manager_entity_name of this ImportableEnterpriseManagerEntity.
        :type: str
        """
        self._enterprise_manager_entity_name = enterprise_manager_entity_name

    @property
    def enterprise_manager_entity_type(self):
        """
        **[Required]** Gets the enterprise_manager_entity_type of this ImportableEnterpriseManagerEntity.
        Enterprise Manager Entity Type


        :return: The enterprise_manager_entity_type of this ImportableEnterpriseManagerEntity.
        :rtype: str
        """
        return self._enterprise_manager_entity_type

    @enterprise_manager_entity_type.setter
    def enterprise_manager_entity_type(self, enterprise_manager_entity_type):
        """
        Sets the enterprise_manager_entity_type of this ImportableEnterpriseManagerEntity.
        Enterprise Manager Entity Type


        :param enterprise_manager_entity_type: The enterprise_manager_entity_type of this ImportableEnterpriseManagerEntity.
        :type: str
        """
        self._enterprise_manager_entity_type = enterprise_manager_entity_type

    @property
    def enterprise_manager_entity_identifier(self):
        """
        **[Required]** Gets the enterprise_manager_entity_identifier of this ImportableEnterpriseManagerEntity.
        Enterprise Manager Entity Unique Identifier


        :return: The enterprise_manager_entity_identifier of this ImportableEnterpriseManagerEntity.
        :rtype: str
        """
        return self._enterprise_manager_entity_identifier

    @enterprise_manager_entity_identifier.setter
    def enterprise_manager_entity_identifier(self, enterprise_manager_entity_identifier):
        """
        Sets the enterprise_manager_entity_identifier of this ImportableEnterpriseManagerEntity.
        Enterprise Manager Entity Unique Identifier


        :param enterprise_manager_entity_identifier: The enterprise_manager_entity_identifier of this ImportableEnterpriseManagerEntity.
        :type: str
        """
        self._enterprise_manager_entity_identifier = enterprise_manager_entity_identifier

    @property
    def opsi_entity_type(self):
        """
        Gets the opsi_entity_type of this ImportableEnterpriseManagerEntity.
        Operations Insights internal representation of the resource type.


        :return: The opsi_entity_type of this ImportableEnterpriseManagerEntity.
        :rtype: str
        """
        return self._opsi_entity_type

    @opsi_entity_type.setter
    def opsi_entity_type(self, opsi_entity_type):
        """
        Sets the opsi_entity_type of this ImportableEnterpriseManagerEntity.
        Operations Insights internal representation of the resource type.


        :param opsi_entity_type: The opsi_entity_type of this ImportableEnterpriseManagerEntity.
        :type: str
        """
        self._opsi_entity_type = opsi_entity_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ContainerScanResultProblem(object):
    """
    A problem found in a container scan
    """

    #: A constant which can be used with the severity property of a ContainerScanResultProblem.
    #: This constant has a value of "NONE"
    SEVERITY_NONE = "NONE"

    #: A constant which can be used with the severity property of a ContainerScanResultProblem.
    #: This constant has a value of "LOW"
    SEVERITY_LOW = "LOW"

    #: A constant which can be used with the severity property of a ContainerScanResultProblem.
    #: This constant has a value of "MEDIUM"
    SEVERITY_MEDIUM = "MEDIUM"

    #: A constant which can be used with the severity property of a ContainerScanResultProblem.
    #: This constant has a value of "HIGH"
    SEVERITY_HIGH = "HIGH"

    #: A constant which can be used with the severity property of a ContainerScanResultProblem.
    #: This constant has a value of "CRITICAL"
    SEVERITY_CRITICAL = "CRITICAL"

    #: A constant which can be used with the state property of a ContainerScanResultProblem.
    #: This constant has a value of "OPEN"
    STATE_OPEN = "OPEN"

    #: A constant which can be used with the state property of a ContainerScanResultProblem.
    #: This constant has a value of "FIXED"
    STATE_FIXED = "FIXED"

    #: A constant which can be used with the state property of a ContainerScanResultProblem.
    #: This constant has a value of "NOT_APPLICABLE"
    STATE_NOT_APPLICABLE = "NOT_APPLICABLE"

    def __init__(self, **kwargs):
        """
        Initializes a new ContainerScanResultProblem object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ContainerScanResultProblem.
        :type name: str

        :param description:
            The value to assign to the description property of this ContainerScanResultProblem.
        :type description: str

        :param severity:
            The value to assign to the severity property of this ContainerScanResultProblem.
            Allowed values for this property are: "NONE", "LOW", "MEDIUM", "HIGH", "CRITICAL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type severity: str

        :param state:
            The value to assign to the state property of this ContainerScanResultProblem.
            Allowed values for this property are: "OPEN", "FIXED", "NOT_APPLICABLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type state: str

        :param cve_reference:
            The value to assign to the cve_reference property of this ContainerScanResultProblem.
        :type cve_reference: str

        """
        self.swagger_types = {
            'name': 'str',
            'description': 'str',
            'severity': 'str',
            'state': 'str',
            'cve_reference': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'description': 'description',
            'severity': 'severity',
            'state': 'state',
            'cve_reference': 'cveReference'
        }

        self._name = None
        self._description = None
        self._severity = None
        self._state = None
        self._cve_reference = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ContainerScanResultProblem.
        Name of the problem


        :return: The name of this ContainerScanResultProblem.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ContainerScanResultProblem.
        Name of the problem


        :param name: The name of this ContainerScanResultProblem.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this ContainerScanResultProblem.
        Problem description


        :return: The description of this ContainerScanResultProblem.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ContainerScanResultProblem.
        Problem description


        :param description: The description of this ContainerScanResultProblem.
        :type: str
        """
        self._description = description

    @property
    def severity(self):
        """
        **[Required]** Gets the severity of this ContainerScanResultProblem.
        Problem severity

        Allowed values for this property are: "NONE", "LOW", "MEDIUM", "HIGH", "CRITICAL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The severity of this ContainerScanResultProblem.
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """
        Sets the severity of this ContainerScanResultProblem.
        Problem severity


        :param severity: The severity of this ContainerScanResultProblem.
        :type: str
        """
        allowed_values = ["NONE", "LOW", "MEDIUM", "HIGH", "CRITICAL"]
        if not value_allowed_none_or_none_sentinel(severity, allowed_values):
            severity = 'UNKNOWN_ENUM_VALUE'
        self._severity = severity

    @property
    def state(self):
        """
        Gets the state of this ContainerScanResultProblem.
        State of the vulnerability

        Allowed values for this property are: "OPEN", "FIXED", "NOT_APPLICABLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The state of this ContainerScanResultProblem.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ContainerScanResultProblem.
        State of the vulnerability


        :param state: The state of this ContainerScanResultProblem.
        :type: str
        """
        allowed_values = ["OPEN", "FIXED", "NOT_APPLICABLE"]
        if not value_allowed_none_or_none_sentinel(state, allowed_values):
            state = 'UNKNOWN_ENUM_VALUE'
        self._state = state

    @property
    def cve_reference(self):
        """
        Gets the cve_reference of this ContainerScanResultProblem.
        Reference to problem MITRE CVE ID


        :return: The cve_reference of this ContainerScanResultProblem.
        :rtype: str
        """
        return self._cve_reference

    @cve_reference.setter
    def cve_reference(self, cve_reference):
        """
        Sets the cve_reference of this ContainerScanResultProblem.
        Reference to problem MITRE CVE ID


        :param cve_reference: The cve_reference of this ContainerScanResultProblem.
        :type: str
        """
        self._cve_reference = cve_reference

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AvailablePluginSummary(object):
    """
    Describes where the plugin is supported
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AvailablePluginSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this AvailablePluginSummary.
        :type name: str

        :param summary:
            The value to assign to the summary property of this AvailablePluginSummary.
        :type summary: str

        :param is_supported:
            The value to assign to the is_supported property of this AvailablePluginSummary.
        :type is_supported: bool

        :param is_enabled_by_default:
            The value to assign to the is_enabled_by_default property of this AvailablePluginSummary.
        :type is_enabled_by_default: bool

        """
        self.swagger_types = {
            'name': 'str',
            'summary': 'str',
            'is_supported': 'bool',
            'is_enabled_by_default': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'summary': 'summary',
            'is_supported': 'isSupported',
            'is_enabled_by_default': 'isEnabledByDefault'
        }

        self._name = None
        self._summary = None
        self._is_supported = None
        self._is_enabled_by_default = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this AvailablePluginSummary.
        The plugin name


        :return: The name of this AvailablePluginSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AvailablePluginSummary.
        The plugin name


        :param name: The name of this AvailablePluginSummary.
        :type: str
        """
        self._name = name

    @property
    def summary(self):
        """
        Gets the summary of this AvailablePluginSummary.
        A brief description of the plugin functionality


        :return: The summary of this AvailablePluginSummary.
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """
        Sets the summary of this AvailablePluginSummary.
        A brief description of the plugin functionality


        :param summary: The summary of this AvailablePluginSummary.
        :type: str
        """
        self._summary = summary

    @property
    def is_supported(self):
        """
        **[Required]** Gets the is_supported of this AvailablePluginSummary.
        Is the plugin supported or not


        :return: The is_supported of this AvailablePluginSummary.
        :rtype: bool
        """
        return self._is_supported

    @is_supported.setter
    def is_supported(self, is_supported):
        """
        Sets the is_supported of this AvailablePluginSummary.
        Is the plugin supported or not


        :param is_supported: The is_supported of this AvailablePluginSummary.
        :type: bool
        """
        self._is_supported = is_supported

    @property
    def is_enabled_by_default(self):
        """
        **[Required]** Gets the is_enabled_by_default of this AvailablePluginSummary.
        Is the plugin enabled or disabled by default


        :return: The is_enabled_by_default of this AvailablePluginSummary.
        :rtype: bool
        """
        return self._is_enabled_by_default

    @is_enabled_by_default.setter
    def is_enabled_by_default(self, is_enabled_by_default):
        """
        Sets the is_enabled_by_default of this AvailablePluginSummary.
        Is the plugin enabled or disabled by default


        :param is_enabled_by_default: The is_enabled_by_default of this AvailablePluginSummary.
        :type: bool
        """
        self._is_enabled_by_default = is_enabled_by_default

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
